@@ -83,6 +83,7 @@ static struct argp_option cmdline_options[] =
     ARGP_COMMON_SDR_CACHE_OPTIONS,
     ARGP_COMMON_SDR_CACHE_OPTIONS_FILE_DIRECTORY,
     ARGP_COMMON_SDR_CACHE_OPTIONS_IGNORE,
+    ARGP_COMMON_SDR_CACHE_OPTIONS_LEGACY,
     ARGP_COMMON_TIME_OPTIONS,
     ARGP_COMMON_HOSTRANGED_OPTIONS,
     ARGP_COMMON_OPTIONS_DEBUG,
@@ -95,7 +96,7 @@ static struct argp_option cmdline_options[] =
       "Skip FRU checksum checks", 42},
     { "bridge-fru", BRIDGE_FRU_KEY, 0, 0,
       "Bridge to read FRU entries on other controllers", 43},
-    { "interpret-oem-data", INTERPRET_OEM_DATA, NULL, 0,
+    { "interpret-oem-data", INTERPRET_OEM_DATA_KEY, NULL, 0,
       "Attempt to interpret OEM data.", 44},
     { "fru-file", FRU_FILE_KEY, "FILENAME", 0,
       "Output from specified FRU binary file.", 45},
@@ -122,7 +123,7 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
   int tmp;
 
   assert (state);
-  
+
   cmd_args = state->input;
 
   switch (key)
@@ -131,12 +132,12 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
       errno = 0;
       tmp = strtol (arg, &endptr, 0);
       if (errno
-	  || endptr[0] != '\0')
+          || endptr[0] != '\0')
         {
           fprintf (stderr, "invalid device id\n");
           exit (EXIT_FAILURE);
         }
-      
+
       if (tmp == IPMI_FRU_DEVICE_ID_RESERVED
           || tmp < IPMI_FRU_DEVICE_ID_MIN
           || tmp > IPMI_FRU_DEVICE_ID_MAX)
@@ -157,7 +158,7 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
     case BRIDGE_FRU_KEY:
       cmd_args->bridge_fru = 1;
       break;
-    case INTERPRET_OEM_DATA:
+    case INTERPRET_OEM_DATA_KEY:
       cmd_args->interpret_oem_data = 1;
       break;
     case FRU_FILE_KEY:
@@ -215,13 +216,13 @@ _ipmi_fru_args_validate (struct ipmi_fru_arguments *cmd_args)
   if (cmd_args->fru_file)
     {
       if (access (cmd_args->fru_file, R_OK) < 0)
-	{
-	  fprintf (stderr,
-		   "Cannot read '%s': %s\n",
-		   cmd_args->fru_file,
-		   strerror (errno));
-	  exit (EXIT_FAILURE);
-	}
+        {
+          fprintf (stderr,
+                   "Cannot read '%s': %s\n",
+                   cmd_args->fru_file,
+                   strerror (errno));
+          exit (EXIT_FAILURE);
+        }
     }
 }
 
